@@ -23,6 +23,7 @@ from math import exp, sqrt
 from pymatgen.core.periodic_table import Element, Specie
 from pymatgen.core.structure import Structure
 from pymatgen.symmetry.finder import SymmetryFinder
+from pymatgen.core.periodic_table import get_el_sp
 
 #Let's initialize some module level properties.
 
@@ -51,7 +52,7 @@ with open(os.path.join(module_dir, "icsd_bv.json"), "r") as f:
                   for sp, data in all_data["occurrence"].items()}
 
 
-def calculate_bv_sum(site, nn_list, scale_factor=1):
+def calculate_bv_sum(site, nn_list, scale_factor=1.0):
     """
     Calculates the BV sum of a site.
 
@@ -99,9 +100,12 @@ def calculate_bv_sum_unordered(site, nn_list, scale_factor=1):
             esp in the case of calculation-relaxed structures which may tend
             to under (GGA) or over bind (LDA).
     """
-    # If the site "site" has N partial occupations as : f_{site}_0, f_{site}_1, ... f_{site}_N of elements
-    # X_{site}_0, X_{site}_1, ... X_{site}_N, and each neighbors nn_i in nn has N_{nn_i} partial occupations as :
-    # f_{nn_i}_0, f_{nn_i}_1, ..., f_{nn_i}_{N_{nn_i}}, then the bv sum of site "site" is obtained as :
+    # If the site "site" has N partial occupations as : f_{site}_0,
+    # f_{site}_1, ... f_{site}_N of elements
+    # X_{site}_0, X_{site}_1, ... X_{site}_N, and each neighbors nn_i in nn
+    # has N_{nn_i} partial occupations as :
+    # f_{nn_i}_0, f_{nn_i}_1, ..., f_{nn_i}_{N_{nn_i}}, then the bv sum of
+    # site "site" is obtained as :
     # \sum_{nn} \sum_j^N \sum_k^{N_{nn}} f_{site}_j f_{nn_i}_k vij_full
     # where vij_full is the valence bond of the fully occupied bond
     bvsum = 0
@@ -156,7 +160,9 @@ class BVAnalyzer(object):
     CHARGE_NEUTRALITY_TOLERANCE = 0.00001
 
     def __init__(self, symm_tol=0.1, max_radius=4, max_permutations=100000,
-                 distance_scale_factor=1.015, charge_neutrality_tolerance=CHARGE_NEUTRALITY_TOLERANCE):
+                 distance_scale_factor=1.015,
+                 charge_neutrality_tolerance=CHARGE_NEUTRALITY_TOLERANCE,
+                 forbidden_species=None):
         """
         Args:
             symm_tol:
@@ -175,19 +181,30 @@ class BVAnalyzer(object):
             charge_neutrality_tolerance:
                 Tolerance on the charge neutrality when unordered structures
                 are at stake.
+            forbidden_species:
+                List of species that are forbidden (example : ["O-"] cannot be
+                used) It is used when e.g. someone knows that some oxidation
+                state cannot occur for some atom in a structure or list of
+                structures.
         """
         self.symm_tol = symm_tol
         self.max_radius = max_radius
         self.max_permutations = max_permutations
         self.dist_scale_factor = distance_scale_factor
         self.charge_neutrality_tolerance = charge_neutrality_tolerance
+        forbidden_species = [get_el_sp(sp) for sp in forbidden_species] if \
+            forbidden_species else []
+        self.icsd_bv_data = {get_el_sp(specie): data
+                             for specie, data in ICSD_BV_DATA.items()
+                             if not specie in forbidden_species} \
+            if len(forbidden_species) > 0 else ICSD_BV_DATA
 
     def _calc_site_probabilities(self, site, nn):
         el = site.specie.symbol
         bv_sum = calculate_bv_sum(site, nn,
                                   scale_factor=self.dist_scale_factor)
         prob = {}
-        for sp, data in ICSD_BV_DATA.items():
+        for sp, data in self.icsd_bv_data.items():
             if sp.symbol == el and sp.oxi_state != 0 and data["std"] > 0:
                 u = data["mean"]
                 sigma = data["std"]
@@ -204,22 +221,27 @@ class BVAnalyzer(object):
         return prob
 
     def _calc_site_probabilities_unordered(self, site, nn):
-        bv_sum = calculate_bv_sum_unordered(site, nn,
-                                            scale_factor=self.dist_scale_factor)
+        bv_sum = calculate_bv_sum_unordered(
+            site, nn, scale_factor=self.dist_scale_factor)
         prob = {}
         for specie, occu in site.species_and_occu.iteritems():
             el = specie.symbol
 
             prob[el] = {}
-            for sp, data in ICSD_BV_DATA.items():
+            for sp, data in self.icsd_bv_data.items():
                 if sp.symbol == el and sp.oxi_state != 0 and data["std"] > 0:
                     u = data["mean"]
                     sigma = data["std"]
                     #Calculate posterior probability. Note that constant
                     #factors are ignored. They have no effect on the results.
-                    prob[el][sp.oxi_state] = exp(-(bv_sum - u) ** 2 / 2 / (sigma ** 2)) / sigma * PRIOR_PROB[sp]
+                    prob[el][sp.oxi_state] = exp(-(bv_sum - u) ** 2 / 2 /
+                                                 (sigma ** 2)) \
+                        / sigma * PRIOR_PROB[sp]
             #Normalize the probabilities
-            prob[el] = {k: v / sum(prob[el].values()) for k, v in prob[el].items()}
+            try:
+                prob[el] = {k: v / sum(prob[el].values()) for k, v in prob[el].items()}
+            except ZeroDivisionError:
+                prob[el] = {k: 0.0 for k in prob[el]}
         return prob
 
     def get_valences(self, structure):
@@ -231,11 +253,14 @@ class BVAnalyzer(object):
             structure: Structure to analyze
 
         Returns:
-            A list of valences for each site in the structure,
-            e.g., [1, 1, -2].
+            A list of valences for each site in the structure (for an ordered
+            structure), e.g., [1, 1, -2] or a list of lists with the
+            valences for each fractional element of each site in the
+            structure (for an unordered structure),
+            e.g., [[2, 4], [3], [-2], [-2], [-2]]
 
         Raises:
-            A ValueError is the valences cannot be determined.
+            A ValueError if the valences cannot be determined.
         """
         els = [Element(el.symbol) for el in structure.composition.elements]
 
@@ -259,9 +284,9 @@ class BVAnalyzer(object):
 
         #Get a list of valences and probabilities for each symmetrically
         #distinct site.
+        valences = []
+        all_prob = []
         if structure.is_ordered:
-            valences = []
-            all_prob = []
             for sites in equi_sites:
                 test_site = sites[0]
                 nn = structure.get_neighbors(test_site, self.max_radius)
@@ -274,8 +299,6 @@ class BVAnalyzer(object):
                 valences.append(filter(lambda v: prob[v] > 0.01 * prob[val[0]],
                                        val))
         else:
-            valences = []
-            all_prob = []
             full_all_prob = []
             for sites in equi_sites:
                 test_site = sites[0]
@@ -284,13 +307,17 @@ class BVAnalyzer(object):
                 all_prob.append(prob)
                 full_all_prob.extend(prob.values())
                 vals = []
-                for el in prob:
-                    val = list(prob[el].keys())
+                for (elsp, occ) in get_z_ordered_elmap(
+                        test_site.species_and_occu):
+                    val = list(prob[elsp.symbol].keys())
                     #Sort valences in order of decreasing probability.
-                    val = sorted(val, key=lambda v: -prob[el][v])
-                    #Retain probabilities that are at least 1/100 of highest prob.
-                    vals.append(filter(lambda v: prob[el][v] > 0.001 * prob[el][val[0]],
-                                       val))
+                    val = sorted(val, key=lambda v: -prob[elsp.symbol][v])
+                    # Retain probabilities that are at least 1/100 of highest
+                    # prob.
+                    vals.append(
+                        filter(lambda v: prob[elsp.symbol][v] >
+                               0.001 * prob[elsp.symbol][val[0]],
+                               val))
                 valences.append(vals)
 
         #make variables needed for recursion
@@ -355,8 +382,10 @@ class BVAnalyzer(object):
                     attrib.append(insite)
             new_nsites = np.array(tmp)
             fractions = []
+            elements = []
             for sites in equi_sites:
-                for sp, occu in sites[0].species_and_occu.iteritems():
+                for sp, occu in get_z_ordered_elmap(sites[0].species_and_occu):
+                    elements.append(sp.symbol)
                     fractions.append(occu)
             fractions = np.array(fractions, np.float)
             new_valences = []
@@ -374,14 +403,17 @@ class BVAnalyzer(object):
                 el_oxi = collections.defaultdict(list)
                 jj = 0
                 for i, sites in enumerate(equi_sites):
-                    for specie in sites[0].species_and_occu:
+                    for specie, occu in get_z_ordered_elmap(
+                            sites[0].species_and_occu):
                         el_oxi[specie.symbol].append(v_set[jj])
                         jj += 1
                 max_diff = max([max(v) - min(v) for v in el_oxi.values()])
                 if max_diff > 2:
                     return
-                score = reduce(operator.mul, [full_all_prob[i][v]
-                                              for i, v in enumerate(v_set)])
+
+                score = reduce(operator.mul,
+                                [all_prob[attrib[iv]][elements[iv]][vv]
+                                 for iv, vv in enumerate(v_set)])
                 if score > self._best_score:
                     self._best_vset = v_set
                     self._best_score = score
@@ -405,7 +437,8 @@ class BVAnalyzer(object):
                 lowest *= fractions
                 lowest = np.sum(lowest)
 
-                if highest < -self.charge_neutrality_tolerance or lowest > self.charge_neutrality_tolerance:
+                if (highest < -self.charge_neutrality_tolerance or
+                        lowest > self.charge_neutrality_tolerance):
                     self._n += 1
                     return
 
@@ -430,16 +463,17 @@ class BVAnalyzer(object):
                 return [int(assigned[site]) for site in structure]
             else:
                 assigned = {}
-                unordered_best_vset = []
+                new_best_vset = []
                 for ii in range(len(equi_sites)):
-                    unordered_best_vset.append(list())
+                    new_best_vset.append(list())
                 for ival, val in enumerate(self._best_vset):
-                    unordered_best_vset[attrib[ival]].append(val)
-                for val, sites in zip(unordered_best_vset, equi_sites):
+                    new_best_vset[attrib[ival]].append(val)
+                for val, sites in zip(new_best_vset, equi_sites):
                     for site in sites:
                         assigned[site] = val
 
-                return [[int(frac_site) for frac_site in assigned[site]] for site in structure]
+                return [[int(frac_site) for frac_site in assigned[site]]
+                        for site in structure]
         else:
             raise ValueError("Valences cannot be assigned!")
 
@@ -458,9 +492,49 @@ class BVAnalyzer(object):
             ValueError if the valences cannot be determined.
         """
         s = Structure.from_sites(structure.sites)
-        valences = self.get_valences(structure)
         if structure.is_ordered:
+            valences = self.get_valences(structure)
             s.add_oxidation_state_by_site(valences)
         else:
-            s.add_oxidation_state_by_site_fraction(valences)
+            valences = self.get_valences(structure)
+            s = add_oxidation_state_by_site_fraction(s, valences)
         return s
+
+
+def get_z_ordered_elmap(comp):
+    """
+    Arbitrary ordered elmap on the elements/species of a composition of a
+    given site in an unordered structure. Returns a list of tuples (
+    element_or_specie: occupation) in the arbitrary order.
+
+    The arbitrary order is based on the Z of the element and the smallest
+    fractional occupations first.
+    Example : {"Ni3+": 0.2, "Ni4+": 0.2, "Cr3+": 0.15, "Zn2+": 0.34,
+    "Cr4+": 0.11} will yield the species in the following order :
+    Cr4+, Cr3+, Ni3+, Ni4+, Zn2+ ... or
+    Cr4+, Cr3+, Ni4+, Ni3+, Zn2+
+    """
+    return sorted([(elsp, comp.elmap[elsp]) for elsp in comp.elmap.keys()])
+
+
+def add_oxidation_state_by_site_fraction(structure, oxidation_states):
+        """
+        Add oxidation states to a structure by fractional site.
+
+        Args:
+            oxidation_states (list): List of list of oxidation states for each
+                site fraction for each site.
+                E.g., [[2, 4], [3], [-2], [-2], [-2]]
+        """
+        try:
+            for i, site in enumerate(structure):
+                new_sp = collections.defaultdict(float)
+                for j, (el, occu) in enumerate(get_z_ordered_elmap(site
+                        .species_and_occu)):
+                    specie = Specie(el.symbol, oxidation_states[i][j])
+                    new_sp[specie] += occu
+                structure[i] = new_sp
+            return structure
+        except IndexError:
+            raise ValueError("Oxidation state of all sites must be "
+                             "specified in the list.")
\ No newline at end of file
