@@ -22,10 +22,11 @@ try:
 except ImportError:
     pass
 
+from monty.json import loadf as json_load
 from pymatgen.core.design_patterns import Enum, AttrDict
 from pymatgen.util.io_utils import FileLock
 from pymatgen.util.string_utils import stream_has_colours, is_string, list_strings, WildCard
-from pymatgen.serializers.json_coders import MSONable, json_load, json_pretty_dump
+from pymatgen.serializers.json_coders import MSONable, json_pretty_dump
 from pymatgen.io.abinitio.utils import File, Directory, irdvars_for_ext, abi_splitext, abi_extensions, FilepathFixer, Condition
 
 from pymatgen.io.abinitio.qadapters import qadapter_class
@@ -121,7 +122,7 @@ class TaskResults(dict, MSONable):
 
     @classmethod
     def json_load(cls, filename):
-        return cls.from_dict(json_load(filename))    
+        return cls.from_dict(load(filename))
 
 
 class ParalHintsError(Exception):
@@ -908,7 +909,7 @@ class Node(object):
         except AttributeError:
             return os.path.relpath(self.workdir)
 
-    def set_name(name):
+    def set_name(self, name):
         """Set the name of the Node."""
         self._name = name
 
