@@ -20,7 +20,7 @@ from pymatgen.transformations.standard_transformations \
     import SubstitutionTransformation
 from pymatgen.alchemy.transmuters import StandardTransmuter
 from pymatgen.alchemy.materials import TransformedStructure
-from pymatgen.alchemy.filters import RemoveDuplicatesFilter
+from pymatgen.alchemy.filters import RemoveDuplicatesFilter, RemoveExistingFilter
 import itertools
 import logging
 from operator import mul
@@ -63,13 +63,21 @@ class Substitutor(MSONable):
         return self._sp.species
 
     def pred_from_structures(self, target_species, structures_list,
-                             remove_duplicates=True):
+                             remove_duplicates=True, remove_existing=False):
         """
-        performs a structure prediction targeting compounds containing the
-        target_species and based on a list of structure (those structures
+        performs a structure prediction targeting compounds containing all of 
+        the target_species, based on a list of structure (those structures
         can for instance come from a database like the ICSD). It will return
         all the structures formed by ionic substitutions with a probability
         higher than the threshold
+        
+        Notes:
+        If the default probability model is used, input structures must
+        be oxidation state decorated.
+        
+        This method does not change the number of species in a structure. i.e
+        if the number of target species is 3, only input structures containing
+        3 species will be considered.
 
         Args:
             target_species:
@@ -79,7 +87,15 @@ class Substitutor(MSONable):
             structures_list:
                 a list of dictionnary of the form {'structure':Structure object
                 ,'id':some id where it comes from}
-                the id can for instance refer to an ICSD id
+                the id can for instance refer to an ICSD id.
+
+            remove_duplicates:
+                if True, the duplicates in the predicted structures will
+                be removed
+
+            remove_existing:
+                if True, the predicted structures that already exist in the
+                structures_list will be removed
 
         Returns:
             a list of TransformedStructure objects.
@@ -113,7 +129,8 @@ class Substitutor(MSONable):
                     if Substitutor._is_charge_balanced(
                             transf.apply_transformation(s['structure'])):
                         ts = TransformedStructure(
-                            s['structure'], [transf], history=[s['id']],
+                            s['structure'], [transf], 
+                            history=[{"source": s['id']}],
                             other_parameters={
                                 'type': 'structure_prediction',
                                 'proba': self._sp.cond_prob_list(permut, els)}
@@ -124,6 +141,15 @@ class Substitutor(MSONable):
         if remove_duplicates:
             transmuter.apply_filter(RemoveDuplicatesFilter(
                 symprec=self._symprec))
+        if remove_existing:
+            #Make the list of structures from structures_list that corresponds to the
+            #target species
+            chemsys = list(set([sp.symbol for sp in target_species]))
+            structures_list_target = [st['structure'] for st in structures_list
+                                      if Substitutor._is_from_chemical_system(chemsys,
+                                                                              st['structure'])]
+            transmuter.apply_filter(RemoveExistingFilter(structures_list_target,
+                                                         symprec=self._symprec))
         return transmuter.transformed_structures
 
     @staticmethod
@@ -136,6 +162,19 @@ class Substitutor(MSONable):
         else:
             return False
 
+    @staticmethod
+    def _is_from_chemical_system(chemical_system, struct):
+        """
+        checks if the structure object is from the given chemical system
+        """
+        chemsys = list(set([sp.symbol for sp in struct.composition]))
+        if len(chemsys) != len(chemical_system):
+            return False
+        for el in chemsys:
+            if not el in chemical_system:
+                return False
+        return True
+
     def pred_from_list(self, species_list):
         """
         There are an exceptionally large number of substitutions to
